@@ -1,4 +1,4 @@
-# Version 1.4-1
+# Version 1.5-1
 
 import re
 import sys
@@ -32,10 +32,10 @@ def numerically_sorted_entities (l):
     E.g. sorted order should be n1, n2, n10; not n1, n10, n2.
     """
 
-    return sorted(l, key=entitiy_numeric_sort_key)
+    return sorted(l, key=entity_numeric_sort_key)
 
 nsk_re = re.compile("([0-9]+)|([^0-9]+)")
-def entitiy_numeric_sort_key(x):
+def entity_numeric_sort_key(x):
     return [handle_int_nonint(i_ni) for i_ni in nsk_re.findall(x.name)]
 
 def handle_int_nonint(int_nonint_tuple):
@@ -210,8 +210,8 @@ class Hierarchy:
         return res
 
     # This is the method invoked by "nodes --to-nodes" (default) 
-    def expand(self, nodespec):
-        return collect_name_hostlist(self.expand_to_node_set(nodespec))
+    def to_nodes(self, nodespec):
+        return self.expand_to_node_set(nodespec)
 
     # This is the central logic behind up, fill and gather
     # Returns a tuple of sets (groups, leftovers, missing):
@@ -251,7 +251,7 @@ class Hierarchy:
                                    (level,
                                     collect_name_hostlist(missing)))
 
-        return collect_name_hostlist(groups)
+        return groups
 
 
     # This is the method invoked by "nodes --fill"
@@ -270,7 +270,7 @@ class Hierarchy:
 
         for group in groups:
             res |= group.expand_to_node_set()
-        return collect_name_hostlist(res)
+        return res
 
     # This is the method invoked by "nodes --representative"
     def representative(self, level, nodespec):
@@ -288,7 +288,7 @@ class Hierarchy:
 
         for group in groups:
             res.add(group.get_representative())
-        return collect_name_hostlist(res)
+        return res
 
     # This is the method invoked by "nodes --gather"
     def gather(self, level, nodespec):
@@ -300,7 +300,7 @@ class Hierarchy:
                                  (level,
                                   collect_name_hostlist(missing)))
 
-        return collect_name_hostlist(groups|leftovers|missing)
+        return groups|leftovers|missing
 
 
 
